# Installation

## Stable release

To install `cmomy`, run this command in your terminal:

```bash
pip install cmomy
```

or

```bash
conda install -c conda-forge cmomy
```

This is the preferred method to install `cmomy`, as it will always install the
most recent stable release.

## From sources

See [](./contributing) for details on installing from source.
